@@ -1,5 +1,9 @@
 import copy
+import inspect
+import sys
 import time
+import traceback
+import warnings
 from collections import defaultdict
 
 import cloudpickle
@@ -14,11 +18,16 @@ from evalml.automl.automl_algorithm import IterativeAlgorithm
 from evalml.automl.callbacks import log_error_callback
 from evalml.automl.engine import SequentialEngine
 from evalml.automl.utils import (
+    AutoMLConfig,
     check_all_pipeline_names_unique,
     get_default_primary_search_objective,
     make_data_splitter
 )
-from evalml.exceptions import AutoMLSearchException, PipelineNotFoundError
+from evalml.exceptions import (
+    AutoMLSearchException,
+    PipelineNotFoundError,
+    PipelineScoreError
+)
 from evalml.model_family import ModelFamily
 from evalml.objectives import (
     get_core_objectives,
@@ -29,6 +38,7 @@ from evalml.pipelines import (
     MeanBaselineRegressionPipeline,
     ModeBaselineBinaryPipeline,
     ModeBaselineMulticlassPipeline,
+    PipelineBase,
     TimeSeriesBaselineBinaryPipeline,
     TimeSeriesBaselineMulticlassPipeline,
     TimeSeriesBaselineRegressionPipeline
@@ -36,15 +46,18 @@ from evalml.pipelines import (
 from evalml.pipelines.components.utils import get_estimators
 from evalml.pipelines.utils import make_pipeline
 from evalml.preprocessing import split_data
-from evalml.problem_types import ProblemTypes, handle_problem_types
+from evalml.problem_types import (
+    ProblemTypes,
+    handle_problem_types,
+    is_time_series
+)
 from evalml.tuners import SKOptTuner
 from evalml.utils import convert_to_seconds, infer_feature_types
 from evalml.utils.logger import (
     get_logger,
     log_subtitle,
     log_title,
-    time_elapsed,
-    update_pipeline
+    time_elapsed
 )
 
 logger = get_logger(__file__)
@@ -83,7 +96,8 @@ class AutoMLSearch:
                  train_best_pipeline=True,
                  pipeline_parameters=None,
                  _ensembling_split_size=0.2,
-                 _pipelines_per_batch=5):
+                 _pipelines_per_batch=5,
+                 engine=None):
         """Automated pipeline search
 
         Arguments:
@@ -166,6 +180,9 @@ class AutoMLSearch:
 
             _pipelines_per_batch (int): The number of pipelines to train for every batch after the first one.
                 The first batch will train a baseline pipline + one of each pipeline family allowed in the search.
+
+            engine (EngineBase or None): The engine instance used to evaluate pipelines. If None, a SequentialEngine will
+                be used.
         """
         if X_train is None:
             raise ValueError('Must specify training data as a 2d array using the X_train argument')
@@ -176,6 +193,10 @@ class AutoMLSearch:
         except ValueError:
             raise ValueError('choose one of (binary, multiclass, regression) as problem_type')
 
+        if is_time_series(self.problem_type):
+            warnings.warn("Time series support in evalml is still in beta, which means we are still actively building "
+                          "its core features. Please be mindful of that when running search().")
+
         self.tuner_class = tuner_class or SKOptTuner
         self.start_iteration_callback = start_iteration_callback
         self.add_result_callback = add_result_callback
@@ -231,7 +252,6 @@ class AutoMLSearch:
         self._results = {
             'pipeline_results': {},
             'search_order': [],
-            'errors': []
         }
         self.random_seed = random_seed
         self.n_jobs = n_jobs
@@ -242,6 +262,10 @@ class AutoMLSearch:
         except ImportError:
             logger.warning("Unable to import plotly; skipping pipeline search plotting\n")
 
+        if allowed_pipelines is not None and not isinstance(allowed_pipelines, list):
+            raise ValueError("Parameter allowed_pipelines must be either None or a list!")
+        if allowed_pipelines is not None and not all(inspect.isclass(p) and issubclass(p, PipelineBase) for p in allowed_pipelines):
+            raise ValueError("Every element of allowed_pipelines must be a subclass of PipelineBase!")
         self.allowed_pipelines = allowed_pipelines
         self.allowed_model_families = allowed_model_families
         self._automl_algorithm = None
@@ -271,6 +295,14 @@ class AutoMLSearch:
             allowed_estimators = get_estimators(self.problem_type, self.allowed_model_families)
             logger.debug(f"allowed_estimators set to {[estimator.name for estimator in allowed_estimators]}")
             self.allowed_pipelines = [make_pipeline(self.X_train, self.y_train, estimator, self.problem_type, custom_hyperparameters=self.pipeline_parameters) for estimator in allowed_estimators]
+        else:
+            for pipeline_class in self.allowed_pipelines:
+                if self.pipeline_parameters:
+                    if pipeline_class.custom_hyperparameters:
+                        for component_name, params in self.pipeline_parameters.items():
+                            pipeline_class.custom_hyperparameters[component_name] = params
+                    else:
+                        pipeline_class.custom_hyperparameters = self.pipeline_parameters
 
         if self.allowed_pipelines == []:
             raise ValueError("No allowed pipelines to search")
@@ -313,13 +345,15 @@ class AutoMLSearch:
             _, ensembling_indices, _, _ = split_data(X_shape, self.y_train, problem_type=self.problem_type, test_size=_ensembling_split_size, random_seed=self.random_seed)
             self.ensembling_indices = ensembling_indices.to_dataframe()[0].tolist()
 
-        self._engine = SequentialEngine(self.X_train,
-                                        self.y_train,
-                                        self.ensembling_indices,
-                                        self,
-                                        should_continue_callback=self._should_continue,
-                                        pre_evaluation_callback=self._pre_evaluation_callback,
-                                        post_evaluation_callback=self._post_evaluation_callback)
+        if not engine:
+            self._engine = SequentialEngine()
+        else:
+            self._engine = engine
+
+        self.automl_config = AutoMLConfig(self.ensembling_indices,
+                                          self.data_splitter, self.problem_type,
+                                          self.objective, self.additional_objectives, self.optimize_thresholds,
+                                          self.error_callback, self.random_seed)
 
         self.allowed_model_families = list(set([p.model_family for p in (self.allowed_pipelines)]))
 
@@ -342,23 +376,15 @@ class AutoMLSearch:
             pipeline_params=pipeline_params
         )
 
-    def _pre_evaluation_callback(self, pipeline):
-        if self.start_iteration_callback:
-            self.start_iteration_callback(pipeline.__class__, pipeline.parameters, self)
-        desc = f"{pipeline.name}"
-        if len(desc) > AutoMLSearch._MAX_NAME_LEN:
-            desc = desc[:AutoMLSearch._MAX_NAME_LEN - 3] + "..."
-        desc = desc.ljust(AutoMLSearch._MAX_NAME_LEN)
+    def _get_batch_number(self):
         batch_number = 1
         if self._automl_algorithm is not None and self._automl_algorithm.batch_number > 0:
             batch_number = self._automl_algorithm.batch_number
-        update_pipeline(logger,
-                        desc,
-                        len(self._results['pipeline_results']) + 1,
-                        self.max_iterations,
-                        self._start,
-                        batch_number,
-                        self.show_batch_output)
+        return batch_number
+
+    def _pre_evaluation_callback(self, pipeline):
+        if self.start_iteration_callback:
+            self.start_iteration_callback(pipeline.__class__, pipeline.parameters, self)
 
     def _validate_objective(self, objective):
         non_core_objectives = get_non_core_objectives()
@@ -487,6 +513,7 @@ class AutoMLSearch:
         new_pipeline_ids = []
         loop_interrupted = False
         while self._should_continue():
+            computations = []
             try:
                 if not loop_interrupted:
                     current_batch_pipelines = self._automl_algorithm.next_batch()
@@ -494,15 +521,34 @@ class AutoMLSearch:
                 logger.info('AutoML Algorithm out of recommendations, ending')
                 break
             try:
-                new_pipeline_ids = self._engine.evaluate_batch(current_batch_pipelines)
+                new_pipeline_ids = []
+                log_title(logger, f"Evaluating Batch Number {self._get_batch_number()}")
+                for pipeline in current_batch_pipelines:
+                    self._pre_evaluation_callback(pipeline)
+                    computation = self._engine.submit_evaluation_job(self.automl_config, pipeline, self.X_train, self.y_train)
+                    computations.append(computation)
+                current_computation_index = 0
+                while self._should_continue() and len(computations) > 0:
+                    computation = computations[current_computation_index]
+                    if computation.done():
+                        evaluation = computation.get_result()
+                        data, pipeline, job_log = evaluation.get('scores'), evaluation.get("pipeline"), evaluation.get("logger")
+                        pipeline_id = self._post_evaluation_callback(pipeline, data, job_log)
+                        new_pipeline_ids.append(pipeline_id)
+                        computations.pop(current_computation_index)
+                    current_computation_index = (current_computation_index + 1) % max(len(computations), 1)
+                    time.sleep(0.1)
                 loop_interrupted = False
             except KeyboardInterrupt:
                 loop_interrupted = True
                 if self._handle_keyboard_interrupt():
-                    break
+                    self._interrupted = True
+                    for computation in computations:
+                        computation.cancel()
+
             full_rankings = self.full_rankings
             current_batch_idx = full_rankings['id'].isin(new_pipeline_ids)
-            current_batch_pipeline_scores = full_rankings[current_batch_idx]['score']
+            current_batch_pipeline_scores = full_rankings[current_batch_idx]["mean_cv_score"]
             if len(current_batch_pipeline_scores) and current_batch_pipeline_scores.isna().all():
                 raise AutoMLSearchException(f"All pipelines in the current AutoML batch produced a score of np.nan on the primary objective {self.objective}.")
 
@@ -517,7 +563,7 @@ class AutoMLSearch:
             best_pipeline = self.rankings.iloc[0]
             best_pipeline_name = best_pipeline["pipeline_name"]
             logger.info(f"Best pipeline: {best_pipeline_name}")
-            logger.info(f"Best pipeline {self.objective.name}: {best_pipeline['score']:3f}")
+            logger.info(f"Best pipeline {self.objective.name}: {best_pipeline['mean_cv_score']:3f}")
         self._searched = True
 
     def _find_best_pipeline(self):
@@ -535,8 +581,8 @@ class AutoMLSearch:
                     train_indices = self.data_splitter.transform_sample(X_train, y_train)
                     X_train = X_train.iloc[train_indices]
                     y_train = y_train.iloc[train_indices]
-                best_pipeline = self._engine.train_pipeline(best_pipeline, X_train, y_train,
-                                                            self.optimize_thresholds, self.objective)
+                best_pipeline = self._engine.submit_training_job(self.automl_config, best_pipeline,
+                                                                 X_train, y_train).get_result()
             self._best_pipeline = best_pipeline
 
     def _num_pipelines(self):
@@ -556,14 +602,7 @@ class AutoMLSearch:
         if self._interrupted:
             return False
 
-        # for add_to_rankings
-        if self._searched:
-            return True
-
-        # Run at least one pipeline for every search
         num_pipelines = self._num_pipelines()
-        if num_pipelines == 0:
-            return True
 
         # check max_time and max_iterations
         elapsed = time.time() - self._start
@@ -577,10 +616,10 @@ class AutoMLSearch:
             return True
 
         first_id = self._results['search_order'][0]
-        best_score = self._results['pipeline_results'][first_id]['score']
+        best_score = self._results['pipeline_results'][first_id]["mean_cv_score"]
         num_without_improvement = 0
         for id in self._results['search_order'][1:]:
-            curr_score = self._results['pipeline_results'][id]['score']
+            curr_score = self._results['pipeline_results'][id]["mean_cv_score"]
             significant_change = abs((curr_score - best_score) / best_score) > self.tolerance
             score_improved = curr_score > best_score if self.objective.greater_is_better else curr_score < best_score
             if score_improved and significant_change:
@@ -621,7 +660,12 @@ class AutoMLSearch:
             max_delay = self.problem_configuration['max_delay']
             baseline = pipeline_class(parameters={"pipeline": {"gap": gap, "max_delay": max_delay},
                                                   "Time Series Baseline Estimator": {"gap": gap, "max_delay": max_delay}})
-        self._engine.evaluate_batch([baseline])
+        self._pre_evaluation_callback(baseline)
+        logger.info(f"Evaluating Baseline Pipeline: {baseline.name}")
+        computation = self._engine.submit_evaluation_job(self.automl_config, baseline, self.X_train, self.y_train)
+        evaluation = computation.get_result()
+        data, pipeline, job_log = evaluation.get('scores'), evaluation.get("pipeline"), evaluation.get("logger")
+        self._post_evaluation_callback(pipeline, data, job_log)
 
     @staticmethod
     def _get_mean_cv_scores_for_all_objectives(cv_data, objective_name_to_class):
@@ -636,12 +680,14 @@ class AutoMLSearch:
                     scores[field] += value
         return {objective: float(score) / n_folds for objective, score in scores.items()}
 
-    def _post_evaluation_callback(self, pipeline, evaluation_results):
+    def _post_evaluation_callback(self, pipeline, evaluation_results, job_log):
+        job_log.write_to_logger(logger)
         training_time = evaluation_results['training_time']
         cv_data = evaluation_results['cv_data']
         cv_scores = evaluation_results['cv_scores']
         is_baseline = pipeline.model_family == ModelFamily.BASELINE
         cv_score = cv_scores.mean()
+        cv_sd = cv_scores.std()
 
         percent_better_than_baseline = {}
         mean_cv_all_objectives = self._get_mean_cv_scores_for_all_objectives(cv_data, self.objective_name_to_class)
@@ -656,7 +702,7 @@ class AutoMLSearch:
                                                                           self._baseline_cv_scores.get(obj_name, np.nan))
             percent_better_than_baseline[obj_name] = percent_better
 
-        high_variance_cv = self._check_for_high_variance(pipeline, cv_scores)
+        high_variance_cv = self._check_for_high_variance(pipeline, cv_score, cv_sd)
 
         pipeline_id = len(self._results['pipeline_results'])
         self._results['pipeline_results'][pipeline_id] = {
@@ -665,7 +711,8 @@ class AutoMLSearch:
             "pipeline_class": type(pipeline),
             "pipeline_summary": pipeline.summary,
             "parameters": pipeline.parameters,
-            "score": cv_score,
+            "mean_cv_score": cv_score,
+            "standard_deviation_cv_score": cv_sd,
             "high_variance_cv": high_variance_cv,
             "training_time": training_time,
             "cv_data": cv_data,
@@ -694,17 +741,15 @@ class AutoMLSearch:
             self.add_result_callback(self._results['pipeline_results'][pipeline_id], pipeline, self)
         return pipeline_id
 
-    def _check_for_high_variance(self, pipeline, cv_scores, threshold=0.2):
+    def _check_for_high_variance(self, pipeline, cv_mean, cv_std, threshold=0.2):
         """Checks cross-validation scores and logs a warning if variance is higher than specified threshhold."""
         pipeline_name = pipeline.name
 
         high_variance_cv = False
-        cv_scores_std = cv_scores.std()
-        cv_scores_mean = cv_scores.mean()
-        if cv_scores_std != 0 and cv_scores_mean != 0:
-            high_variance_cv = bool(abs(cv_scores_std / cv_scores_mean) > threshold)
+        if cv_std != 0 and cv_mean != 0:
+            high_variance_cv = bool(abs(cv_std / cv_mean) > threshold)
         if high_variance_cv:
-            logger.warning(f"High coefficient of variation (cv >= {threshold}) within cross validation scores. {pipeline_name} may not perform as estimated on unseen data.")
+            logger.warning(f"\tHigh coefficient of variation (cv >= {threshold}) within cross validation scores.\n\t{pipeline_name} may not perform as estimated on unseen data.")
         return high_variance_cv
 
     def get_pipeline(self, pipeline_id):
@@ -763,7 +808,7 @@ class AutoMLSearch:
 
         for c in all_objective_scores:
             if c in ["# Training", "# Validation"]:
-                all_objective_scores[c] = all_objective_scores[c].astype("object")
+                all_objective_scores[c] = all_objective_scores[c].map(lambda x: '{:2,.0f}'.format(x) if not pd.isna(x) else np.nan)
                 continue
 
             mean = all_objective_scores[c].mean(axis=0)
@@ -791,7 +836,10 @@ class AutoMLSearch:
             if pipeline.parameters == parameter:
                 return
 
-        self._engine.evaluate_batch([pipeline])
+        computation = self._engine.submit_evaluation_job(self.automl_config, pipeline, self.X_train, self.y_train)
+        evaluation = computation.get_result()
+        data, pipeline, job_log = evaluation.get('scores'), evaluation.get("pipeline"), evaluation.get("logger")
+        self._post_evaluation_callback(pipeline, data, job_log)
         self._find_best_pipeline()
 
     @property
@@ -815,14 +863,14 @@ class AutoMLSearch:
         if self.objective.greater_is_better:
             ascending = False
 
-        full_rankings_cols = ["id", "pipeline_name", "score", "validation_score",
-                              "percent_better_than_baseline", "high_variance_cv", "parameters"]
+        full_rankings_cols = ["id", "pipeline_name", "mean_cv_score", "standard_deviation_cv_score",
+                              "validation_score", "percent_better_than_baseline", "high_variance_cv", "parameters"]
         if not self._results['pipeline_results']:
             return pd.DataFrame(columns=full_rankings_cols)
 
         rankings_df = pd.DataFrame(self._results['pipeline_results'].values())
         rankings_df = rankings_df[full_rankings_cols]
-        rankings_df.sort_values("score", ascending=ascending, inplace=True)
+        rankings_df.sort_values("mean_cv_score", ascending=ascending, inplace=True)
         rankings_df.reset_index(drop=True, inplace=True)
         return rankings_df
 
@@ -877,7 +925,36 @@ class AutoMLSearch:
             Note that the any pipelines that error out during training will not be included in the dictionary
             but the exception and stacktrace will be displayed in the log.
         """
-        return self._engine.train_batch(pipelines)
+        check_all_pipeline_names_unique(pipelines)
+        fitted_pipelines = {}
+        computations = []
+        X_train = self.X_train
+        y_train = self.y_train
+
+        # Apply sampling
+        if hasattr(self.data_splitter, "transform_sample"):
+            train_indices = self.data_splitter.transform_sample(X_train, y_train)
+            X_train = X_train.iloc[train_indices]
+            y_train = y_train.iloc[train_indices]
+
+        for pipeline in pipelines:
+            computations.append(self._engine.submit_training_job(self.automl_config, pipeline, X_train, y_train))
+
+        while computations:
+            computation = computations.pop(0)
+            if computation.done():
+                try:
+                    fitted_pipeline = computation.get_result()
+                    fitted_pipelines[fitted_pipeline.name] = fitted_pipeline
+                except Exception as e:
+                    logger.error(f'Train error for {pipeline.name}: {str(e)}')
+                    tb = traceback.format_tb(sys.exc_info()[2])
+                    logger.error("Traceback:")
+                    logger.error("\n".join(tb))
+            else:
+                computations.append(computation)
+
+        return fitted_pipelines
 
     def score_pipelines(self, pipelines, X_holdout, y_holdout, objectives):
         """Score a list of pipelines on the given holdout data.
@@ -893,4 +970,32 @@ class AutoMLSearch:
             Note that the any pipelines that error out during scoring will not be included in the dictionary
             but the exception and stacktrace will be displayed in the log.
         """
-        return self._engine.score_batch(pipelines, X_holdout, y_holdout, objectives)
+        check_all_pipeline_names_unique(pipelines)
+        scores = {}
+        objectives = [get_objective(o, return_instance=True) for o in objectives]
+
+        computations = []
+        for pipeline in pipelines:
+            computations.append(self._engine.submit_scoring_job(self.automl_config, pipeline, X_holdout, y_holdout, objectives))
+
+        while computations:
+            computation = computations.pop(0)
+            if computation.done():
+                pipeline_name = computation.meta_data["pipeline_name"]
+                try:
+                    scores[pipeline_name] = computation.get_result()
+                except Exception as e:
+                    logger.error(f"Score error for {pipeline_name}: {str(e)}")
+                    if isinstance(e, PipelineScoreError):
+                        nan_scores = {objective: np.nan for objective in e.exceptions}
+                        scores[pipeline_name] = {**nan_scores, **e.scored_successfully}
+                    else:
+                        # Traceback already included in the PipelineScoreError so we only
+                        # need to include it for all other errors
+                        tb = traceback.format_tb(sys.exc_info()[2])
+                        logger.error("Traceback:")
+                        logger.error("\n".join(tb))
+                        scores[pipeline_name] = {objective.name: np.nan for objective in objectives}
+            else:
+                computations.append(computation)
+        return scores
