@@ -1,3 +1,5 @@
+from collections import namedtuple
+
 import pandas as pd
 from sklearn.model_selection import KFold
 
@@ -110,3 +112,8 @@ def check_all_pipeline_names_unique(pipelines):
         plural, tense = ("s", "were") if len(duplicate_names) > 1 else ("", "was")
         duplicates = ", ".join([f"'{name}'" for name in sorted(duplicate_names)])
         raise ValueError(f"All pipeline names must be unique. The name{plural} {duplicates} {tense} repeated.")
+
+
+AutoMLConfig = namedtuple("AutoMLConfig", ["ensembling_indices", "data_splitter", "problem_type",
+                                           "objective", "additional_objectives", "optimize_thresholds",
+                                           "error_callback", "random_seed"])
