@@ -8,10 +8,10 @@ from evalml.exceptions import MissingComponentError
 from evalml.model_family.utils import handle_model_family
 from evalml.pipelines.components import ComponentBase, Estimator, Transformer
 from evalml.problem_types import ProblemTypes, handle_problem_types
-from evalml.utils import get_logger
-from evalml.utils.gen_utils import (
+from evalml.utils import (
     _convert_woodwork_types_wrapper,
-    get_importable_subclasses
+    get_importable_subclasses,
+    get_logger
 )
 
 logger = get_logger(__file__)
