@@ -53,7 +53,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """Returns list or dictionary of components representing pipeline graph structure
 
         Returns:
-            list(str / ComponentBase subclass): List of ComponentBase subclasses or strings denotes graph structure of this pipeline
+            list(str / ComponentBase subclass): List of ComponentBase subclasses or strings denotes graph structure of this pipeline.
         """
 
     custom_hyperparameters = None
@@ -64,7 +64,11 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """Machine learning pipeline made out of transformers and a estimator.
 
         Required Class Variables:
-            component_graph (list): List of components in order. Accepts strings or ComponentBase subclasses in the list
+            component_graph (list or dict): List of components in order. Accepts strings or ComponentBase subclasses in the list.
+                Note that when duplicate components are specified in a list, the duplicate component names will be modified with the
+                component's index in the list. For example, the component graph
+                [Imputer, One Hot Encoder, Imputer, Logistic Regression Classifier] will have names
+                ["Imputer", "One Hot Encoder", "Imputer_2", "Logistic Regression Classifier"]
 
         Arguments:
             parameters (dict): Dictionary with component names as keys and dictionary of that component's parameters as values.
@@ -108,7 +112,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """Returns a short summary of the pipeline structure, describing the list of components used.
         Example: Logistic Regression Classifier w/ Simple Imputer + One Hot Encoder
         """
-        component_graph = [handle_component_class(component_class) for component_class in copy.copy(cls.linearized_component_graph)]
+        component_graph = [handle_component_class(component_class) for _, component_class in copy.copy(cls.linearized_component_graph)]
         if len(component_graph) == 0:
             return "Empty Pipeline"
         summary = "Pipeline"
@@ -125,10 +129,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
     @classproperty
     def linearized_component_graph(cls):
         """Returns a component graph in list form. Note: this is not guaranteed to be in proper component computation order"""
-        if isinstance(cls.component_graph, list):
-            return cls.component_graph
-        else:
-            return [component_info[0] for component_info in cls.component_graph.values()]
+        return ComponentGraph.linearized_component_graph(cls.component_graph)
 
     def _validate_estimator_problem_type(self):
         """Validates this pipeline's problem_type against that of the estimator from `self.component_graph`"""
@@ -312,21 +313,11 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
     def hyperparameters(cls):
         """Returns hyperparameter ranges from all components as a dictionary"""
         hyperparameter_ranges = dict()
-        component_graph = copy.copy(cls.component_graph)
-        if isinstance(component_graph, list):
-            for component_class in component_graph:
-                component_class = handle_component_class(component_class)
-                component_hyperparameters = copy.copy(component_class.hyperparameter_ranges)
-                if cls.custom_hyperparameters and component_class.name in cls.custom_hyperparameters:
-                    component_hyperparameters.update(cls.custom_hyperparameters.get(component_class.name, {}))
-                hyperparameter_ranges[component_class.name] = component_hyperparameters
-        else:
-            for component_name, component_info in component_graph.items():
-                component_class = handle_component_class(component_info[0])
-                component_hyperparameters = copy.copy(component_class.hyperparameter_ranges)
-                if cls.custom_hyperparameters and component_name in cls.custom_hyperparameters:
-                    component_hyperparameters.update(cls.custom_hyperparameters.get(component_name, {}))
-                hyperparameter_ranges[component_name] = component_hyperparameters
+        for component_name, component_class in cls.linearized_component_graph:
+            component_hyperparameters = copy.copy(component_class.hyperparameter_ranges)
+            if cls.custom_hyperparameters and component_name in cls.custom_hyperparameters:
+                component_hyperparameters.update(cls.custom_hyperparameters.get(component_name, {}))
+            hyperparameter_ranges[component_name] = component_hyperparameters
         return hyperparameter_ranges
 
     @property
