@@ -128,6 +128,12 @@ def X_y_binary():
     return X, y
 
 
+@pytest.fixture(scope="class")
+def X_y_binary_cls(request):
+    request.cls.X_y_binary = datasets.make_classification(n_samples=100, n_features=20,
+                                                          n_informative=2, n_redundant=2, random_state=0)
+
+
 @pytest.fixture
 def X_y_regression():
     X, y = datasets.make_regression(n_samples=100, n_features=20,
