@@ -463,8 +463,9 @@ def test_mape_time_series_model():
 def test_calculate_percent_difference(objective_class):
     score = 5
     reference_score = 10
+    denominator = 1 if objective_class.is_bounded_like_percentage else reference_score
 
-    change = ((-1) ** (not objective_class.greater_is_better) * (score - reference_score)) / reference_score
+    change = ((-1) ** (not objective_class.greater_is_better) * (score - reference_score)) / denominator
     answer = 100 * change
 
     assert objective_class.calculate_percent_difference(score, reference_score) == answer
@@ -478,13 +479,21 @@ def test_calculate_percent_difference_with_nan(objective_class, nan_value):
     assert pd.isna(objective_class.calculate_percent_difference(-1, nan_value))
     assert pd.isna(objective_class.calculate_percent_difference(nan_value, nan_value))
 
-    assert pd.isna(objective_class.calculate_percent_difference(2, 0))
+
+@pytest.mark.parametrize("baseline_score", [0, 1e-11])
+@pytest.mark.parametrize("objective_class", _all_objectives_dict().values())
+def test_calculate_percent_difference_when_baseline_0_or_close_to_0(objective_class, baseline_score):
+    percent_difference = objective_class.calculate_percent_difference(2, baseline_score)
+    if objective_class.is_bounded_like_percentage:
+        assert percent_difference == ((-1) ** (not objective_class.greater_is_better)) * (2 - baseline_score) * 100
+    else:
+        assert np.isinf(percent_difference)
 
 
 def test_calculate_percent_difference_negative_and_equal_numbers():
 
     assert CostBenefitMatrix.calculate_percent_difference(score=5, baseline_score=5) == 0
-
+    assert CostBenefitMatrix.calculate_percent_difference(score=5.003, baseline_score=5.003 - 1e-11) == 0
     assert CostBenefitMatrix.calculate_percent_difference(score=-5, baseline_score=-10) == 50
     assert CostBenefitMatrix.calculate_percent_difference(score=-10, baseline_score=-5) == -100
     assert CostBenefitMatrix.calculate_percent_difference(score=-5, baseline_score=10) == -150
@@ -493,14 +502,27 @@ def test_calculate_percent_difference_negative_and_equal_numbers():
     # These values are not possible for LogLossBinary but we need them for 100% coverage
     # We might add an objective where lower is better that can take negative values in the future
     assert LogLossBinary.calculate_percent_difference(score=-5, baseline_score=-10) == -50
+    assert LogLossBinary.calculate_percent_difference(score=5.003, baseline_score=5.003 + 1e-11) == 0
     assert LogLossBinary.calculate_percent_difference(score=-10, baseline_score=-5) == 100
     assert LogLossBinary.calculate_percent_difference(score=-5, baseline_score=10) == 150
     assert LogLossBinary.calculate_percent_difference(score=10, baseline_score=-5) == -300
 
+    # Verify percent_difference is 0 when numbers are close to equal for objective that is bounded in [0, 1]
+    assert AccuracyBinary.calculate_percent_difference(score=5, baseline_score=5) == 0
+    assert AccuracyBinary.calculate_percent_difference(score=5.003, baseline_score=5.003 + 1e-11) == 0
+
 
 def test_calculate_percent_difference_small():
     expected_value = 100 * -1 * np.abs(1e-9 / (1e-9))
     assert np.isclose(ExpVariance.calculate_percent_difference(score=0, baseline_score=1e-9), expected_value, atol=1e-8)
-    assert pd.isna(ExpVariance.calculate_percent_difference(score=0, baseline_score=1e-10))
-    assert pd.isna(ExpVariance.calculate_percent_difference(score=1e-9, baseline_score=0))
-    assert pd.isna(ExpVariance.calculate_percent_difference(score=0, baseline_score=0))
+    assert ExpVariance.calculate_percent_difference(score=0, baseline_score=1e-10) == 0
+    assert ExpVariance.calculate_percent_difference(score=2e-10, baseline_score=1e-10) == 0
+    assert np.isinf(ExpVariance.calculate_percent_difference(score=1e-9, baseline_score=0))
+    assert np.isinf(ExpVariance.calculate_percent_difference(score=0.1, baseline_score=1e-11))
+
+    expected_value = 100 * np.abs(1e-9)
+    assert np.isclose(AccuracyBinary.calculate_percent_difference(score=0, baseline_score=1e-9), expected_value, atol=1e-6)
+    assert AccuracyBinary.calculate_percent_difference(score=0, baseline_score=1e-10) == 0
+    assert AccuracyBinary.calculate_percent_difference(score=2e-10, baseline_score=1e-10) == 0
+    assert np.isclose(AccuracyBinary.calculate_percent_difference(score=1e-9, baseline_score=0), expected_value, atol=1e-6)
+    assert np.isclose(AccuracyBinary.calculate_percent_difference(score=0.1, baseline_score=1e-11), 100 * np.abs(0.1 - 1e-11), atol=1e-6)
