@@ -1,4 +1,6 @@
 import numpy as np
+import pandas as pd
+from pandas.testing import assert_series_equal
 
 from evalml.pipelines import BaselineRegressionPipeline
 
@@ -13,7 +15,10 @@ def test_baseline_mean(X_y_regression):
     }
     clf = BaselineRegressionPipeline(parameters=parameters)
     clf.fit(X, y)
-    np.testing.assert_allclose(clf.predict(X), np.array([mean] * len(X)))
+
+    expected_predictions = pd.Series([mean] * len(X))
+    predictions = clf.predict(X)
+    assert_series_equal(expected_predictions, predictions.to_series())
     np.testing.assert_allclose(clf.feature_importance.iloc[:, 1], np.array([0.0] * X.shape[1]))
 
 
@@ -27,5 +32,7 @@ def test_baseline_median(X_y_regression):
     }
     clf = BaselineRegressionPipeline(parameters=parameters)
     clf.fit(X, y)
-    np.testing.assert_allclose(clf.predict(X), np.array([median] * len(X)))
+    expected_predictions = pd.Series([median] * len(X))
+    predictions = clf.predict(X)
+    assert_series_equal(expected_predictions, predictions.to_series())
     np.testing.assert_allclose(clf.feature_importance.iloc[:, 1], np.array([0.0] * X.shape[1]))
